/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.bayernid.proxy;

import java.time.ZonedDateTime;
import java.util.GregorianCalendar;
import java.util.UUID;

import javax.xml.datatype.DatatypeFactory;

import lombok.SneakyThrows;

public class GrpcBayernIdMessageMetadataTestFactory {

	public static final String MESSAGE_ID = "messageId";
	public static final ZonedDateTime CREATED_AT = ZonedDateTime.now();
	public static final String CREATED_AT_STRING = convertZoneDDateTime(CREATED_AT);
	public static final String STORK_QAA_LEVEL = "LEVEL_1";
	public static final String SUBJECT = "subject";
	public static final String VORGANG_ID = UUID.randomUUID().toString();
	public static final String MESSAGE_TEXT = "some completely random text";

	public static GrpcBayernIdMessageMetadata create() {
		return createBuilder().build();
	}

	public static GrpcBayernIdMessageMetadata.Builder createBuilder() {
		return GrpcBayernIdMessageMetadata.newBuilder()
				.setMessageId(MESSAGE_ID)
				.setCreatedAt(convertZoneDDateTime(CREATED_AT))
				.setAbsender(GrpcAbsenderTestFactory.create())
				.setEmpfaenger(GrpcEmpfaengerTestFactory.create())
				.setSubject(SUBJECT)
				.setStorkQaaLevel(STORK_QAA_LEVEL)
				.setVorgangId(VORGANG_ID)
				.setText(MESSAGE_TEXT);
	}

	@SneakyThrows
	public static String convertZoneDDateTime(ZonedDateTime dateTime) {
		return DatatypeFactory.newInstance().newXMLGregorianCalendar(GregorianCalendar.from(dateTime)).toString();
	}
}
